{% load i18n %}

<div class="dashboard-item">
  <div class="dashboard-item-header">
    <span class="dashboard-item-header-title">
      {{ item.title }}
    </span>
    <div class="cf"></div>
  </div>

  <div class="dashboard-item-content{% if item.contrast %} contrast{% endif %}">
    {% include item.template_name with item=item %}
  </div>
</div>
