{% load i18n stats_tags %}
<li>
  <a href="{% get_stats_link %}" class="button">
    {% trans "Show stats" %}
    &nbsp;
    <span class="changeform-navigation-button-icon right icon-arrow-right"></span>
  </a>
</li>
