.form-row p {
    margin-bottom: 0;
}

/*
 * List filter popup fixes.
 */

.changelist-filter-popup-content.visible {
    position: fixed;
    top: 50%;
    left: 50%;
    width: min(90%, 420px);
    min-width: 320px;
    transform: translateX(-50%) translateY(-50%);
    max-height: 100%;
    overflow: auto;
    z-index: 100500;
    box-shadow: 0 34px 6rem 0 rgba(71, 186, 193, 0.75);
}

.changelist-filter-popup-content .controls {
    padding: 1rem;
    padding-top: 0;
}

.changelist-filter-popup-content .form-row {
    padding-left: 0;
    padding-right: 0;
}

/*
 * List table totals.
 */

.results #result_list thead>tr:nth-child(2) th {
    background: #d0dbe6;
    color: #6f7e95;
    border-radius: 0;
}

.results #result_list thead>tr:nth-child(2) th:first-child {
    text-align: center;
}

.results #result_list thead>tr:nth-child(2) th:first-child b {
    display: none;
}

.results #result_list thead>tr:nth-child(2) th:first-child:before {
    content: "\1D6BA"
}

/*
 * Array form widget.
 */

.dynamic-array-widget .array-item:not(:last-child) {
    margin-bottom: 4px;
}

.dynamic-array-widget .array-item .remove .inline-deletelink:before {
    color: red;
    content: '\00D7';
    font-size: 1.4em;
    font-weight: bold;
}