{% load stats_tags %}

<div id="chart-{{ item.key }}">
  <svg style="min-height: 250px" />
</div>

<script>

createChart(
  {{ item.key|stats_json|safe }},
  {{ item.result|stats_json|safe }},
  {{ item.config|stats_json|safe }},
);

</script>
